#qr-invite-page{
    width: 256px;
}
.invite-download-button {
    max-width: 160px;
}
.clear-both {
    clear: both;
}
.bd-callout {
    padding: 1.25rem;
    margin-top: 1.25rem;
    margin-bottom: 1.25rem;
    background-color: var(--bd-callout-bg, var(--bs-gray-100));
    border-left:0.25rem solid var(--bd-callout-border, var(--bs-gray-300))
}
.bd-callout h4 {
    margin-bottom:.25rem
}
.bd-callout > :last-child {
    margin-bottom:0
}
.bd-callout + .bd-callout {
    margin-top:-.25rem
}
.bd-callout .highlight {
    background-color:rgba(0, 0, 0, 0.05)
}
.bd-callout-info {
    --bd-callout-bg: rgba(var(--bs-info-rgb), .075);
    --bd-callout-border: rgba(var(--bs-info-rgb), .5)
}
.bd-callout-warning {
    --bd-callout-bg: rgba(var(--bs-warning-rgb), .075);
    --bd-callout-border: rgba(var(--bs-warning-rgb), .5)
}
.bd-callout-danger {
    --bd-callout-bg: rgba(var(--bs-danger-rgb), .075);
    --bd-callout-border: rgba(var(--bs-danger-rgb), .5)
}
.fa-w-11 {
    width: .6875em;
}
.fa-w-16 {
    widht: 1em;
}
.svg-inline--fa {
    display: inline-block;
    font-size: inherit;
    height: 1em;
    overflow: visible;
    vertical-align: -.125em;
}
